@@ -12,8 +12,9 @@ class String:
         if not (isinstance(other, str) or isinstance(other, bytes)):
             return False
         if self.regex:
-            if isinstance(self.regex, str) and \
-                    not re.fullmatch(self.regex, str(other), self.flags()):
+            if isinstance(self.regex, str) and not re.fullmatch(
+                    self.regex, str(other), self.flags()
+            ):
                 return False
             if isinstance(self.regex, re.Pattern) and not self.regex.fullmatch(other):
                 return False
